@@ -43,10 +43,11 @@ class Arbiter(object):
         if name[:3] == "SIG" and name[3] != "_"
     )
 
-    def __init__(self, address, num_workers, modname, **kwargs):
+    def __init__(self, address, num_workers, app, **kwargs):
         self.address = address
         self.num_workers = num_workers
-        self.modname = modname
+        self.app = app
+        
         self.timeout = 30
         self.reexec_pid = 0
         self.debug = kwargs.get("debug", False)
@@ -55,6 +56,7 @@ class Arbiter(object):
         self.conf = kwargs.get("config", {})
         self._pidfile = None
         self.master_name = "Master"
+        self.proc_name = self.conf['proc_name']
         
         # get current path, try to use PWD env first
         try:
@@ -78,7 +80,7 @@ class Arbiter(object):
         """ Really initialize the arbiter. Strat to listen and set pidfile if needed."""
         self.pid = os.getpid()
         self.init_signals()
-        self.LISTENER = create_socket(self.address)
+        self.LISTENER = create_socket(self.conf)
         self.pidfile = self.opts.get("pidfile")
         self.log.info("Booted Arbiter: %s" % os.getpid())
         self.log.info("Listening on socket: %s" % self.LISTENER)
@@ -160,6 +162,7 @@ class Arbiter(object):
     def run(self):
         """ main master loop. Launch to start the master"""
         self.start()
+        util._setproctitle("master [%s]" % self.proc_name)
         self.manage_workers()
         while True:
             try:
@@ -355,8 +358,8 @@ class Arbiter(object):
             if i in workers:
                 continue
 
-            worker = Worker(i, self.pid, self.LISTENER, self.modname,
-                        self.timeout/2.0, self.debug)
+            worker = Worker(i, self.pid, self.LISTENER, self.app,
+                        self.timeout/2.0, self.conf)
             self.conf.before_fork(self, worker)
             pid = os.fork()
             if pid != 0:
@@ -366,6 +369,7 @@ class Arbiter(object):
             # Process Child
             worker_pid = os.getpid()
             try:
+                util._setproctitle("worker [%s]" % self.proc_name)
                 self.log.debug("Worker %s booting" % worker_pid)
                 self.conf.after_fork(self, worker)
                 worker.run()
